@@ -305,11 +305,11 @@ QString gooStringToUnicode(const std::unique_ptr<GooString> &s)
     }
 
     if (s->hasUnicodeMarker() || s->hasUnicodeMarkerLE()) {
-        return QString::fromUtf16(reinterpret_cast<const ushort*>(s->toStr().c_str()), s->toStr().size() / 2);
+        return QString::fromUtf16(reinterpret_cast<const char16_t*>(s->toStr().c_str()), s->toStr().size() / 2);
     } else {
         int len = 0;
         std::unique_ptr<const char[]> utf16Data(pdfDocEncodingToUTF16(s->toStr(), &len));
-        return QString::fromUtf16(reinterpret_cast<const ushort*>(utf16Data.get()), len / 2);
+        return QString::fromUtf16(reinterpret_cast<const char16_t*>(utf16Data.get()), len / 2);
     }
 
     return QString::fromUtf8(s->c_str());
