@@ -5,6 +5,7 @@
 */
 
 #include "../lib/asn1/berelement.h"
+#include "../lib/era/elbticket.h"
 #include "../lib/era/fcbticket.h"
 #include "../lib/era/ssbv1ticket.h"
 #include "../lib/era/ssbv2ticket.h"
@@ -55,19 +56,19 @@ static void dumpGadget(const void *gadget, const QMetaObject *mo, const char* in
         }
         const auto value = prop.readOnGadget(gadget);
         std::cout << indent << prop.name() << ": " << qPrintable(value.toString()) << std::endl;
-        if (const auto childMo = QMetaType::metaObjectForType(value.userType())) {
+        if (const auto childMo = QMetaType(value.userType()).metaObject()) {
             QByteArray childIndent(indent);
             childIndent.push_back(' ');
             dumpGadget(value.constData(), childMo, childIndent.constData());
-        } else if (value.canConvert<QVariantList>() && value.type() != QVariant::String && value.type() != QVariant::ByteArray) {
+        } else if (value.canConvert<QVariantList>() && value.userType() != QMetaType::QString && value.userType() != QMetaType::QByteArray) {
             auto iterable = value.value<QSequentialIterable>();
             int idx = 0;
             QByteArray childIndent(indent);
             childIndent.append("  ");
             for (const QVariant &v : iterable) {
-                if (QMetaType::metaObjectForType(v.userType())) {
+                if (QMetaType(v.userType()).metaObject()) {
                     std::cout << indent << " [" << idx++ << "]:" << std::endl;
-                    dumpGadget(v.constData(), QMetaType::metaObjectForType(v.userType()), childIndent.constData());
+                    dumpGadget(v.constData(), QMetaType(v.userType()).metaObject(), childIndent.constData());
                 } else {
                     std::cout << indent << " [" << idx++ << "]: "  << qPrintable(v.toString()) << std::endl;
                 }
@@ -116,6 +117,34 @@ static void dumpSsbv1Ticket(const QByteArray &data)
     std::cout << "Departure time: " << qPrintable(ticket.departureTime().toString(Qt::ISODate)) << std::endl;
 }
 
+static void dumpElbTicketSegment(const ELBTicketSegment &segment)
+{
+    dumpGadget(&segment, "  ");
+    std::cout << "  Departure date: "  << qPrintable(segment.departureDate().toString(Qt::ISODate)) << std::endl;
+}
+
+static void dumpElbTicket(const ELBTicket &ticket)
+{
+    const auto mo = &ELBTicket::staticMetaObject;
+    for (auto i = 0; i < mo->propertyCount(); ++i) {
+        const auto prop = mo->property(i);
+        if (!prop.isStored() || QMetaType(prop.userType()).metaObject()) {
+            continue;
+        }
+        const auto value = prop.readOnGadget(&ticket);
+        std::cout << prop.name() << ": " << qPrintable(value.toString()) << std::endl;
+    }
+    std::cout << "Emission date: " << qPrintable(ticket.emissionDate().toString(Qt::ISODate)) << std::endl;
+    std::cout << "Valid from: " << qPrintable(ticket.validFromDate().toString(Qt::ISODate)) << std::endl;
+    std::cout << "Valid until: " << qPrintable(ticket.validUntilDate().toString(Qt::ISODate)) << std::endl;
+    std::cout << std::endl << "Segment 1:" << std::endl;
+    dumpElbTicketSegment(ticket.segment1());
+    if (ticket.segment2().isValid()) {
+        std::cout << std::endl << "Segment 2:" << std::endl;
+        dumpElbTicketSegment(ticket.segment2());
+    }
+}
+
 static void dumpRawData(const char *data, std::size_t size)
 {
     bool isText = true;
@@ -346,6 +375,9 @@ int main(int argc, char **argv)
     } else if (VdvTicketParser::maybeVdvTicket(data)) {
         std::cout << "VDV Ticket" << std::endl;
         dumpVdv(data);
+    } else if (auto ticket = ELBTicket::parse(data); ticket) {
+        std::cout << "ERA ELB Ticket" << std::endl;
+        dumpElbTicket(*ticket);
     } else {
         std::cout << "Unknown content" << std::endl;
         return 1;
